package com.example.technicalsupport.screens

import androidx.compose.ui.test.assertIsDisplayed
import androidx.compose.ui.test.junit4.createComposeRule
import androidx.compose.ui.test.onNodeWithTag
import androidx.compose.ui.test.onNodeWithText
import androidx.compose.ui.test.performClick
import androidx.compose.ui.test.performTextInput
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import com.example.technicalsupport.navigation.AppNavigation
import com.example.technicalsupport.navigation.Screens
import com.example.technicalsupport.ui.theme.TechnicalSupportTheme
import org.junit.Before
import org.junit.Rule
import org.junit.Test

class LogInTest {
    @get:Rule(order = 0)
    var testRule = createComposeRule()

    @Before
    fun setup() {
        testRule.setContent {
            val navController = rememberNavController()
            TechnicalSupportTheme {
                NavHost(navController = navController, startDestination = Screens.LogIn.route) {
                    composable(route = Screens.LogIn.route) {
                        LogIn(navController = navController)
                    }
                    composable(
                        route = Screens.AppNavigation.route + "/{email}/{password}/{last_name}/{first_name}/{patronymic}",
                        arguments = listOf(
                            navArgument("email") {
                                type = NavType.StringType
                            },
                            navArgument("password") {
                                type = NavType.StringType
                            },
                            navArgument("last_name") {
                                type = NavType.StringType
                            },
                            navArgument("first_name") {
                                type = NavType.StringType
                            },
                            navArgument("patronymic") {
                                type = NavType.StringType
                            },
                        )
                    )
                    {
                        val email = it.arguments!!.getString("email")
                        val password = it.arguments!!.getString("password")
                        val last_name = it.arguments!!.getString("last_name")
                        val first_name = it.arguments!!.getString("first_name")
                        val patronymic = it.arguments!!.getString("patronymic")
                        AppNavigation(
                            email = email!!,
                            password = password!!,
                            last_name!!,
                            first_name!!,
                            patronymic!!,
                            navController
                        )

                    }
                }
            }


        }
    }


    @Test
    fun correctPasswordAndLogin() {
        testRule.onNodeWithTag("login").performTextInput("i.a.bolshakov")
        testRule.onNodeWithTag("password").performTextInput("Password123!")
        testRule.onNodeWithTag("enter").performClick()
        testRule.onNodeWithText("Заявки").assertIsDisplayed()

    }

    @Test
    fun incorrectPassword() {
        testRule.onNodeWithTag("CustomEmail").performTextInput("i.a.bolshakov")
        testRule.onNodeWithTag("CustomPassword").performTextInput("123")
        testRule.onNodeWithTag("entrance").performClick()
        testRule.onNodeWithText("Неверно введены почта и/или пароль").assertIsDisplayed()

    }

    @Test
    fun incorrectLogin() {
        testRule.onNodeWithTag("CustomEmail").performTextInput("bolshakov")
        testRule.onNodeWithTag("CustomPassword").performTextInput("Password123!")
        testRule.onNodeWithTag("entrance").performClick()
        testRule.onNodeWithText("Неверно введены почта и/или пароль")
            .assertIsDisplayed()

    }
}