package com.example.technicalsupport.screens

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.testTag
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.technicalsupport.models.Task
import com.example.technicalsupport.ui.theme.Font
import com.google.firebase.Firebase
import com.google.firebase.firestore.firestore

@Composable
fun Applications(last_name: String, first_name: String, patronymic: String) {

    val db = Firebase.firestore
    val tasks = remember {
        mutableStateOf(emptyList<Task>())
    }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(20.dp)
            .padding(vertical = 30.dp)
            .background(MaterialTheme.colorScheme.background),
        horizontalAlignment = Alignment.Start,
        verticalArrangement = Arrangement.Top
    ) {
        Text(
            text = "Заявки",
            fontSize = 30.sp,
            fontFamily = Font,
            fontWeight = FontWeight.Normal,
            color = MaterialTheme.colorScheme.onBackground
        )
        Spacer(modifier = Modifier.height(60.dp))
        db.collection("tasks")
            .whereEqualTo("owner", "$last_name $first_name $patronymic")
            .whereIn("status", listOf("В ожидании", "В работе"))
            .get()
            .addOnCompleteListener {
                if (it.isSuccessful) {
                    tasks.value = it.result.toObjects(Task::class.java)
                }
            }
        if (tasks.value.isNotEmpty()) {
            LazyColumn(
                modifier = Modifier
                    .fillMaxSize()
            ) {
                items(tasks.value) { app ->
                    val index = tasks.value.indexOf(app)
                    val bool = Card_application(app,"app$index")
                    if (!bool) {
                        db.collection("tasks")
                            .whereEqualTo("owner", "$last_name $first_name $patronymic")
                            .whereIn("status", listOf("В ожидании", "В работе"))
                            .get()
                            .addOnCompleteListener {
                                if (it.isSuccessful) {
                                    tasks.value = it.result.toObjects(Task::class.java)
                                }
                            }
                    }
                }
            }


        } else {
            Column(
                modifier = Modifier.fillMaxSize(),
                verticalArrangement = Arrangement.Center,
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                CircularProgressIndicator()

            }
        }
    }


}

@Composable
fun Card_application(tasks: Task, tag:String): Boolean {
    val openDialog = remember { mutableStateOf(false) }
    Spacer(modifier = Modifier.height(10.dp))
    Column(modifier = Modifier
        .fillMaxWidth()
        .clip(shape = RoundedCornerShape(10.dp))
        .background(Color(0xffF5F5F9))
        .border(2.dp, Color(0xffB8C1CC), RoundedCornerShape(10.dp))
        .padding(10.dp)
        .clickable { openDialog.value = true }
        .testTag(tag)
    ) {

        Text(
            text = tasks.description,
            fontSize = 20.sp,
            fontWeight = FontWeight.Medium,
            color = Color.Black
        )
        Text(
            text = tasks.status,
            fontSize = 15.sp,
            fontWeight = FontWeight.Normal,
            color = Color.Black
        )
        Text(
            text = tasks.priority,
            fontSize = 15.sp,
            fontWeight = FontWeight.Normal,
            color = Color.Black
        )
        Text(
            text = tasks.client,
            fontSize = 15.sp,
            fontWeight = FontWeight.Normal,
            color = Color.Black
        )
        Text(
            text = tasks.application_date,
            fontSize = 15.sp,
            fontWeight = FontWeight.Normal,
            color = Color.Black
        )


    }
    if (openDialog.value) {
        DialogTask(onDismiss = { openDialog.value = false }, task = tasks)
    }
    return openDialog.value
}

