package com.example.technicalsupport.screens

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.testTag
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.example.technicalsupport.models.KnowledgeBaseModel
import com.example.technicalsupport.models.Task
import com.example.technicalsupport.ui.theme.Font
import com.google.firebase.Firebase
import com.google.firebase.firestore.firestore

@Composable
fun KnowledgeBase() {
    val openDialog = remember { mutableStateOf(false) }
    val db = Firebase.firestore
    val tasks = remember {
        mutableStateOf(emptyList<KnowledgeBaseModel>())
    }
    val list = remember {
        mutableStateOf(KnowledgeBaseModel())
    }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(20.dp)
            .padding(vertical = 30.dp)
            .background(MaterialTheme.colorScheme.background),
        horizontalAlignment = Alignment.Start,
        verticalArrangement = Arrangement.Top
    ) {
        Text(
            text = "База знаний",
            fontSize = 30.sp,
            fontFamily = Font,
            fontWeight = FontWeight.Normal,
            color = MaterialTheme.colorScheme.onBackground
        )
        Spacer(modifier = Modifier.height(60.dp))
        db.collection("KnowledgeBase")
            .get()
            .addOnCompleteListener {
                if (it.isSuccessful) {
                    tasks.value = it.result.toObjects(KnowledgeBaseModel::class.java)
                }
            }
        if (tasks.value.isNotEmpty()) {
            LazyColumn(
                modifier = Modifier
                    .fillMaxSize()
            ) {
                items(tasks.value) { app ->
                    val index = tasks.value.indexOf(app)
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .clip(shape = RoundedCornerShape(10.dp))
                            .background(Color(0xffF5F5F9))
                            .border(2.dp, Color(0xffB8C1CC), RoundedCornerShape(10.dp))
                            .padding(10.dp)
                            .clickable {
                                list.value = app
                                openDialog.value = true
                            }
                            .testTag("base$index"),
                        horizontalArrangement = Arrangement.Center,
                        verticalAlignment = Alignment.CenterVertically
                    ) {

                        Text(
                            text = app.title,
                            fontSize = 18.sp,
                            fontWeight = FontWeight.Medium,
                            color = Color.Black
                        )
                    }
                    
                    Spacer(modifier = Modifier.height(10.dp))
                }
            }


        } else {
            Column(
                modifier = Modifier.fillMaxSize(),
                verticalArrangement = Arrangement.Center,
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                CircularProgressIndicator()

            }
        }
    }
    if (openDialog.value) {
       KnowledgeBaseDialog(onDismiss = { openDialog.value = false}, base = list.value)
    }
}