package com.example.technicalsupport.screens

import android.util.Patterns
import android.widget.Toast
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.gestures.detectTapGestures
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.ExperimentalComposeUiApi
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalFocusManager
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.platform.testTag
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.technicalsupport.CustomEmail
import com.example.technicalsupport.CustomPassword
import com.example.technicalsupport.R
import com.example.technicalsupport.models.User
import com.example.technicalsupport.navigation.Screens
import com.example.technicalsupport.ui.theme.Font
import com.google.firebase.Firebase
import com.google.firebase.firestore.firestore


@OptIn(ExperimentalComposeUiApi::class)
@Composable
fun LogIn(navController: NavController) {
    val db = Firebase.firestore
    val context = LocalContext.current
    val keyboardController = LocalSoftwareKeyboardController.current
    val focusManager = LocalFocusManager.current
    val password = remember {
        mutableStateOf("")
    }
    val passwordFlag = remember {
        mutableStateOf(false)
    }
    val email = remember {
        mutableStateOf("")
    }
    val emailFlag = remember {
        mutableStateOf(false)
    }
    val users = remember {
        mutableStateOf(emptyList<User>())
    }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(10.dp)
            .padding(vertical = 70.dp)
            .pointerInput(Unit) {
                detectTapGestures(onTap = {
                    keyboardController?.hide()
                    focusManager.clearFocus()
                })
            }
            .background(MaterialTheme.colorScheme.background),
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally
    ) {

        Image(
            painter = painterResource(id = R.drawable.zavod_logo),
            contentDescription = "logo",
            contentScale = ContentScale.FillWidth,
            modifier = Modifier.fillMaxWidth(0.7f)
        )

        Spacer(modifier = Modifier.height(100.dp))
        CustomEmail(
            search = email.value,
            onValueChange = { email.value = it },
            isError = email.value.isEmpty(),
            keyboardController = keyboardController,
            focusManager = focusManager
        )
        Row(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.Start
        ) {
            if (emailFlag.value) {
                Text(
                    text = "Введите логин",
                    color = MaterialTheme.colorScheme.error,
                    textAlign = TextAlign.Start
                )
            }
        }
        Spacer(modifier = Modifier.height(20.dp))
        CustomPassword(
            text = "Пароль",
            search = password.value,
            isError = password.value.isEmpty(),
            onValueChange = { password.value = it })
        Row(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.Start
        ) {
            if (passwordFlag.value) {
                Text(
                    text = "Введите пароль ",
                    color = MaterialTheme.colorScheme.error,
                    textAlign = TextAlign.Start
                )
            }
        }

        Spacer(modifier = Modifier.height(50.dp))

        if (email.value.isNotEmpty() && password.value.isNotEmpty()) {
            Button(
                onClick = {
                    db.collection("users")
                        .whereEqualTo("email", email.value)
                        .whereEqualTo("password", password.value)
                        .get()
                        .addOnCompleteListener {
                            if (it.isSuccessful) {
                                users.value = it.result.toObjects(User::class.java)
                                if (users.value.isEmpty()) {
                                    Toast.makeText(
                                        context, "Неверно введены почта и/или пароль",
                                        Toast.LENGTH_SHORT
                                    ).show()
                                } else {
                                    navController.navigate(
                                        Screens.AppNavigation.withArg(
                                            email.value,
                                            password.value,
                                            users.value.last().last_name,
                                            users.value.last().first_name,
                                            users.value.last().patronymic
                                        )
                                    )
                                }
                            }
                        }
                },

                modifier = Modifier
                    .padding(top = 20.dp)
                    .width(width = 500.dp)
                    .height(height = 56.dp)
                    .testTag("enter"),
                shape = RoundedCornerShape(size = 10.dp),
                colors = ButtonDefaults.buttonColors(

                    containerColor = Color(0xFF1A6FEE),
                    contentColor = Color.White
                )
            ) {
                Text(
                    text = "Войти",
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Normal,
                    fontFamily = Font
                )
            }
        } else {
            Button(
                modifier = Modifier
                    .padding(top = 20.dp)
                    .width(width = 500.dp)
                    .height(height = 56.dp),
                onClick = {
                    emailFlag.value =
                        email.value.isEmpty() || !Patterns.EMAIL_ADDRESS.matcher(email.value)
                            .matches()
                    passwordFlag.value = password.value.isEmpty()
                },
                shape = RoundedCornerShape(size = 10.dp),
                colors = ButtonDefaults.buttonColors(
                    containerColor = Color(0xFF849DC2),
                    contentColor = Color.White
                )
            ) {
                Text(
                    text = "Войти",
                    fontSize = 20.sp,
                    fontWeight = FontWeight.Normal,
                    fontFamily = Font
                )
            }

        }

    }
}