package com.example.technicalsupport.screens

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.testTag
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.technicalsupport.R
import com.example.technicalsupport.models.User
import com.example.technicalsupport.navigation.Screens
import com.example.technicalsupport.ui.theme.Font
import com.google.firebase.Firebase
import com.google.firebase.firestore.firestore

@Composable
fun Profile(email: String, password: String, navController: NavController) {
    val db = Firebase.firestore
    val users = remember {
        mutableStateOf(emptyList<User>())
    }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(20.dp)
            .padding(vertical = 30.dp)
            .background(MaterialTheme.colorScheme.background),
        horizontalAlignment = Alignment.Start,
        verticalArrangement = Arrangement.Top
    ) {
        Row(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.SpaceBetween,
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text(
                text = "Профиль",
                fontSize = 30.sp,
                fontFamily = Font,
                fontWeight = FontWeight.Normal,
                color = MaterialTheme.colorScheme.onBackground
            )
            Image(
                painter = painterResource(id = R.drawable.exit),
                contentDescription = "",
                modifier = Modifier
                    .size(20.dp)
                    .clickable { navController.navigate(Screens.LogIn.route) }
                    .testTag("exit"))

        }

        Spacer(modifier = Modifier.height(60.dp))
        db.collection("users")
            .whereEqualTo("email", email)
            .whereEqualTo("password", password)
            .get()
            .addOnCompleteListener {
                if (it.isSuccessful) {
                    users.value = it.result.toObjects(User::class.java)
                }
            }
        if (users.value.isNotEmpty()) {
            Field(text = users.value.last().last_name)
            Field(text = users.value.last().first_name)
            Field(text = users.value.last().patronymic)
            Field(text = users.value.last().date_of_birth)
            Field(text = users.value.last().working_division)
            Field(text = users.value.last().position)
        } else {
            Column(
                modifier = Modifier.fillMaxSize(),
                verticalArrangement = Arrangement.Center,
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                CircularProgressIndicator()

            }
        }
    }

}

@Composable
fun Field(text: String) {
    Spacer(modifier = Modifier.height(10.dp))
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .clip(shape = RoundedCornerShape(10.dp))
            .background(Color(0xffF5F5F9))
            .border(2.dp, Color(0xffB8C1CC), RoundedCornerShape(10.dp))
            .padding(10.dp)
    ) {

        Text(
            text = text,
            fontSize = 20.sp,
            fontWeight = FontWeight.Normal,
            color = Color.Black
        )
    }
}